@@ -1,13 +1,14 @@
 #' Create a list of datasets.
 #'
 #' @usage dataset(scientificname = NULL, taxonid = NULL, datasetid = NULL,
-#'   nodeid = NULL, areaid = NULL, startdate = NULL, enddate = NULL,
-#'   startdepth = NULL, enddepth = NULL, geometry = NULL, redlist = NULL,
-#'   hab = NULL, wrims = NULL, exclude = NULL, verbose = FALSE)
+#'   nodeid = NULL, instituteid = NULL, areaid = NULL, startdate = NULL,
+#'   enddate = NULL, startdepth = NULL, enddepth = NULL, geometry = NULL,
+#'   redlist = NULL, hab = NULL, wrims = NULL, exclude = NULL, verbose = FALSE)
 #' @param scientificname the scientific name.
 #' @param taxonid the taxon identifier (WoRMS AphiaID).
 #' @param datasetid the dataset identifier.
 #' @param nodeid the OBIS node identifier.
+#' @param instituteid the OBIS institute identifier.
 #' @param areaid the OBIS area identifier.
 #' @param startdate the earliest date on which occurrence took place.
 #' @param enddate the latest date on which the occurrence took place.
@@ -30,6 +31,7 @@ dataset <- function(
   taxonid = NULL,
   datasetid = NULL,
   nodeid = NULL,
+  instituteid = NULL,
   areaid = NULL,
   startdate = NULL,
   enddate = NULL,
@@ -56,6 +58,7 @@ dataset <- function(
       taxonid = handle_vector(taxonid),
       datasetid = handle_vector(datasetid),
       nodeid = handle_vector(nodeid),
+      instituteid = handle_vector(instituteid),
       areaid = handle_vector(areaid),
       startdate = handle_date(startdate),
       enddate = handle_date(enddate),
